@@ -87,7 +87,6 @@ class OrientationDetector {
   int get_orientation();
  private:
   OSResults* osr_;
-  tesseract::Tesseract* tess_;
   const GenericVector<int>* allowed_scripts_;
 };
 
@@ -134,6 +133,6 @@ bool os_detect_blob(BLOBNBOX* bbox, OrientationDetector* o,
 // Helper method to convert an orientation index to its value in degrees.
 // The value represents the amount of clockwise rotation in degrees that must be
 // applied for the text to be upright (readable).
-TESS_API const int OrientationIdToValue(const int& id);
+TESS_API int OrientationIdToValue(const int& id);
 
 #endif  // TESSERACT_CCMAIN_OSDETECT_H__
