@@ -19,9 +19,16 @@
 #include "ccstruct.h"
 
 namespace tesseract  {
-CCStruct::CCStruct()
-  : image_(this) {
-}
+
+// APPROXIMATIONS of the fractions of the character cell taken by
+// the descenders, ascenders, and x-height.
+const double CCStruct::kDescenderFraction = 0.25;
+const double CCStruct::kXHeightFraction = 0.5;
+const double CCStruct::kAscenderFraction = 0.25;
+const double CCStruct::kXHeightCapRatio = CCStruct::kXHeightFraction /
+    (CCStruct::kXHeightFraction + CCStruct::kAscenderFraction);
+
+CCStruct::CCStruct() {}
 
 CCStruct::~CCStruct() {
 }
