@@ -161,10 +161,14 @@ class BLOCK:public ELIST_LINK, public PDBLK
     median_size_.set_y(y);
   }
 
-  Pix* render_mask() {
-    return PDBLK::render_mask(re_rotation_);
+  Pix* render_mask(TBOX* mask_box) {
+    return PDBLK::render_mask(re_rotation_, mask_box);
   }
 
+  // Returns the bounding box including the desired combination of upper and
+  // lower noise/diacritic elements.
+  TBOX restricted_bounding_box(bool upper_dots, bool lower_dots) const;
+
   // Reflects the polygon in the y-axis and recomputes the bounding_box.
   // Does nothing to any contained rows/words/blobs etc.
   void reflect_polygon_in_y_axis();
