@@ -20,13 +20,12 @@
 #ifndef           BASEDIR_H
 #define           BASEDIR_H
 
-#include          "host.h"
+#include          "platform.h"
 #include          "strngs.h"
 
-#include          "notdll.h"     //must be last include
+// Returns the given code_path truncated to the last slash.
+// Useful for getting to the directory of argv[0], but does not search
+// any paths.
+TESS_API void truncate_path(const char *code_path, STRING* trunc_path);
 
-DLLSYM inT8 getpath(                   //get dir name of code
-                    const char *code,  //executable to locate
-                    STRING &path       //output path name
-                   );
 #endif
