@@ -43,11 +43,6 @@ void (*zapper) (void *)) {       //ptr to zapper functn
   CLIST_LINK *ptr;
   CLIST_LINK *next;
 
-  #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST::internal_deep_clear", ABORT, NULL);
-  #endif
-
   if (!empty ()) {
     ptr = last->next;            //set to first
     last->next = NULL;           //break circle
@@ -75,11 +70,6 @@ void CLIST::shallow_clear() {  //destroy all links
   CLIST_LINK *ptr;
   CLIST_LINK *next;
 
-  #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST::shallow_clear", ABORT, NULL);
-  #endif
-
   if (!empty ()) {
     ptr = last->next;            //set to first
     last->next = NULL;           //break circle
@@ -111,11 +101,6 @@ void CLIST::assign_to_sublist(                           //to this list
   const ERRCODE LIST_NOT_EMPTY =
     "Destination list must be empty before extracting a sublist";
 
-  #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST::assign_to_sublist", ABORT, NULL);
-  #endif
-
   if (!empty ())
     LIST_NOT_EMPTY.error ("CLIST.assign_to_sublist", ABORT, NULL);
 
@@ -133,11 +118,6 @@ inT32 CLIST::length() const {  //count elements
   CLIST_ITERATOR it(const_cast<CLIST*>(this));
   inT32 count = 0;
 
-  #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST::length", ABORT, NULL);
-  #endif
-
   for (it.mark_cycle_pt(); !it.cycled_list(); it.forward())
     count++;
   return count;
@@ -160,11 +140,6 @@ const void *, const void *)) {
   void **current;
   inT32 i;
 
-  #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST::sort", ABORT, NULL);
-  #endif
-
   /* Allocate an array of pointers, one per list element */
   count = length ();
   base = (void **) malloc (count * sizeof (void *));
@@ -190,7 +165,7 @@ const void *, const void *)) {
 
 // Assuming list has been sorted already, insert new_data to
 // keep the list sorted according to the same comparison function.
-// Comparision function is the same as used by sort, i.e. uses double
+// Comparison function is the same as used by sort, i.e. uses double
 // indirection. Time is O(1) to add to beginning or end.
 // Time is linear to add pre-sorted items to an empty list.
 // If unique, then don't add duplicate entries.
@@ -272,8 +247,6 @@ void CLIST::set_subtract(int comparator(const void*, const void*),
 
 void *CLIST_ITERATOR::forward() {
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::forward", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::forward", ABORT, NULL);
   #endif
@@ -317,8 +290,6 @@ void *CLIST_ITERATOR::data_relative(                //get data + or - ...
   CLIST_LINK *ptr;
 
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::data_relative", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::data_relative", ABORT, NULL);
   if (list->empty ())
@@ -352,8 +323,6 @@ void *CLIST_ITERATOR::data_relative(                //get data + or - ...
 
 void *CLIST_ITERATOR::move_to_last() {
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::move_to_last", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::move_to_last", ABORT, NULL);
   #endif
@@ -386,8 +355,6 @@ void CLIST_ITERATOR::exchange(                             //positions of 2 link
   CLIST_LINK *old_current;
 
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::exchange", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::exchange", ABORT, NULL);
   if (!other_it)
@@ -490,8 +457,6 @@ CLIST_LINK *CLIST_ITERATOR::extract_sublist(                             //from
   const ERRCODE DONT_EXTRACT_DELETED =
     "Can't extract a sublist marked by deleted points";
 
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::extract_sublist", ABORT, NULL);
   if (!other_it)
     BAD_PARAMETER.error ("CLIST_ITERATOR::extract_sublist", ABORT,
       "other_it NULL");
@@ -513,7 +478,7 @@ CLIST_LINK *CLIST_ITERATOR::extract_sublist(                             //from
 
   temp_it.mark_cycle_pt ();
   do {                           //walk sublist
-    if (temp_it.cycled_list ())  //cant find end pt
+    if (temp_it.cycled_list ())  //can't find end pt
       BAD_SUBLIST.error ("CLIST_ITERATOR.extract_sublist", ABORT, NULL);
 
     if (temp_it.at_last ()) {
