@@ -51,11 +51,11 @@ class DLLSYM CLIST_LINK
     }
 
     CLIST_LINK(                       //copy constructor
-               const CLIST_LINK &) {  //dont copy link
+               const CLIST_LINK &) {  //don't copy link
       data = next = NULL;
     }
 
-    void operator= (             //dont copy links
+    void operator= (             //don't copy links
     const CLIST_LINK &) {
       data = next = NULL;
     }
@@ -89,7 +89,7 @@ class DLLSYM CLIST
     void internal_deep_clear (   //destroy all links
       void (*zapper) (void *));  //ptr to zapper functn
 
-    void shallow_clear();  //clear list but dont
+    void shallow_clear();  //clear list but don't
     //delete data elements
 
     bool empty() const {  //is list empty?
@@ -117,7 +117,7 @@ class DLLSYM CLIST
 
     // Assuming list has been sorted already, insert new_data to
     // keep the list sorted according to the same comparison function.
-    // Comparision function is the same as used by sort, i.e. uses double
+    // Comparison function is the same as used by sort, i.e. uses double
     // indirection. Time is O(1) to add to beginning or end.
     // Time is linear to add pre-sorted items to an empty list.
     // If unique, then don't add duplicate entries.
@@ -232,7 +232,7 @@ class DLLSYM CLIST_ITERATOR
     BOOL8 cycled_list();  //Completed a cycle?
 
     void add_to_end(                  //add at end &
-                    void *new_data);  //dont move
+                    void *new_data);  //don't move
 
     void exchange(                            //positions of 2 links
                   CLIST_ITERATOR *other_it);  //other iterator
@@ -255,8 +255,6 @@ class DLLSYM CLIST_ITERATOR
 inline void CLIST_ITERATOR::set_to_list(  //change list
                                         CLIST *list_to_iterate) {
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::set_to_list", ABORT, NULL);
   if (!list_to_iterate)
     BAD_PARAMETER.error ("CLIST_ITERATOR::set_to_list", ABORT,
       "list_to_iterate is NULL");
@@ -296,8 +294,6 @@ inline void CLIST_ITERATOR::add_after_then_move(  // element to add
   CLIST_LINK *new_element;
 
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::add_after_then_move", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::add_after_then_move", ABORT, NULL);
   if (!new_data)
@@ -346,8 +342,6 @@ inline void CLIST_ITERATOR::add_after_stay_put(  // element to add
   CLIST_LINK *new_element;
 
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::add_after_stay_put", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::add_after_stay_put", ABORT, NULL);
   if (!new_data)
@@ -399,8 +393,6 @@ inline void CLIST_ITERATOR::add_before_then_move(  // element to add
   CLIST_LINK *new_element;
 
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::add_before_then_move", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::add_before_then_move", ABORT, NULL);
   if (!new_data)
@@ -437,7 +429,7 @@ inline void CLIST_ITERATOR::add_before_then_move(  // element to add
 /***********************************************************************
  *							CLIST_ITERATOR::add_before_stay_put
  *
- *  Add a new element to the list before the current element but dont move the
+ *  Add a new element to the list before the current element but don't move the
  *  iterator to the new element.
  **********************************************************************/
 
@@ -446,8 +438,6 @@ inline void CLIST_ITERATOR::add_before_stay_put(  // element to add
   CLIST_LINK *new_element;
 
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::add_before_stay_put", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::add_before_stay_put", ABORT, NULL);
   if (!new_data)
@@ -485,14 +475,12 @@ inline void CLIST_ITERATOR::add_before_stay_put(  // element to add
 /***********************************************************************
  *							CLIST_ITERATOR::add_list_after
  *
- *  Insert another list to this list after the current element but dont move the
+ *  Insert another list to this list after the current element but don't move the
  *  iterator.
  **********************************************************************/
 
 inline void CLIST_ITERATOR::add_list_after(CLIST *list_to_add) {
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::add_list_after", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::add_list_after", ABORT, NULL);
   if (!list_to_add)
@@ -541,8 +529,6 @@ inline void CLIST_ITERATOR::add_list_after(CLIST *list_to_add) {
 
 inline void CLIST_ITERATOR::add_list_before(CLIST *list_to_add) {
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::add_list_before", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::add_list_before", ABORT, NULL);
   if (!list_to_add)
@@ -591,8 +577,6 @@ inline void *CLIST_ITERATOR::extract() {
   void *extracted_data;
 
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::extract", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::extract", ABORT, NULL);
   if (!current)                  //list empty or
@@ -632,8 +616,6 @@ inline void *CLIST_ITERATOR::extract() {
 
 inline void *CLIST_ITERATOR::move_to_first() {
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::move_to_first", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::move_to_first", ABORT, NULL);
   #endif
@@ -658,8 +640,6 @@ inline void *CLIST_ITERATOR::move_to_first() {
 
 inline void CLIST_ITERATOR::mark_cycle_pt() {
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::mark_cycle_pt", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::mark_cycle_pt", ABORT, NULL);
   #endif
@@ -681,8 +661,6 @@ inline void CLIST_ITERATOR::mark_cycle_pt() {
 
 inline BOOL8 CLIST_ITERATOR::at_first() {
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::at_first", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::at_first", ABORT, NULL);
   #endif
@@ -703,8 +681,6 @@ inline BOOL8 CLIST_ITERATOR::at_first() {
 
 inline BOOL8 CLIST_ITERATOR::at_last() {
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::at_last", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::at_last", ABORT, NULL);
   #endif
@@ -725,8 +701,6 @@ inline BOOL8 CLIST_ITERATOR::at_last() {
 
 inline BOOL8 CLIST_ITERATOR::cycled_list() {
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::cycled_list", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::cycled_list", ABORT, NULL);
   #endif
@@ -745,8 +719,6 @@ inline BOOL8 CLIST_ITERATOR::cycled_list() {
 
 inline inT32 CLIST_ITERATOR::length() {
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::length", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::length", ABORT, NULL);
   #endif
@@ -767,8 +739,6 @@ CLIST_ITERATOR::sort (           //sort elements
 int comparator (                 //comparison routine
 const void *, const void *)) {
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::sort", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::sort", ABORT, NULL);
   #endif
@@ -793,8 +763,6 @@ inline void CLIST_ITERATOR::add_to_end(  // element to add
   CLIST_LINK *new_element;
 
   #ifndef NDEBUG
-  if (!this)
-    NULL_OBJECT.error ("CLIST_ITERATOR::add_to_end", ABORT, NULL);
   if (!list)
     NO_LIST.error ("CLIST_ITERATOR::add_to_end", ABORT, NULL);
   if (!new_data)
@@ -836,7 +804,7 @@ Replace <parm> with "<parm>".  <parm> may be an arbitrary number of tokens
 
 CLASSNAME is assumed to be the name of a class to be used in a CONS list
 
-NOTE:  Because we dont use virtual functions in the list code, the list code
+NOTE:  Because we don't use virtual functions in the list code, the list code
 will NOT work correctly for classes derived from this.
 
 The macro generates:
@@ -885,7 +853,7 @@ public:																			\
 							CLASSNAME##_CLIST():CLIST() {}						\
 														/* constructor */		\
 																				\
-							CLASSNAME##_CLIST(	/* dont construct */			\
+							CLASSNAME##_CLIST(	/* don't construct */			\
 	const CLASSNAME##_CLIST&)							/*by initial assign*/	\
 	{ DONT_CONSTRUCT_LIST_BY_COPY.error( QUOTE_IT( CLASSNAME##_CLIST ),			\
 														ABORT, NULL ); }		\
@@ -963,7 +931,7 @@ CLISTIZEH_C( CLASSNAME )
 *  A function which can delete a CLASSNAME element.  This is passed to the		\
 *  generic deep_clear list member function so that when a list is cleared the	\
 *  elements on the list are properly destroyed from the base class, even		\
-*  though we dont use a virtual destructor function.							\
+*  though we don't use a virtual destructor function.							\
 **********************************************************************/			\
 																				\
 DLLSYM void					CLASSNAME##_c1_zapper(		/*delete a link*/		\
