@@ -17,7 +17,6 @@
  *
  **********************************************************************/
 
-#include          "mfcpch.h"     //precompiled headers
 #include          <stdio.h>
 #include          <stdlib.h>
 #include          <stdarg.h>
@@ -55,7 +54,7 @@ const char *format, ...          // special message
   if (format != NULL) {
     msgptr += sprintf (msgptr, ":");
     va_start(args, format);  //variable list
-    #ifdef __MSW32__
+    #ifdef _WIN32
                                  //print remainder
     msgptr += _vsnprintf (msgptr, MAX_MSG - 2 - (msgptr - msg), format, args);
     msg[MAX_MSG - 2] = '\0';     //ensure termination
@@ -72,7 +71,8 @@ const char *format, ...          // special message
                                  //no specific
     msgptr += sprintf (msgptr, "\n");
 
-  fprintf(stderr, msg);
+  // %s is needed here so msg is printed correctly!
+  fprintf(stderr, "%s", msg);
 
   int* p = NULL;
   switch (action) {
