@@ -19,12 +19,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-#ifdef EMBEDDED
+#ifdef HAVE_CONFIG_H
+#include "config_auto.h"
+#endif
 
 #include <ctype.h>
+#include <math.h>
 #include <stdarg.h>
 #include <stddef.h>
-#include <inttypes.h>
 #include <string.h>
 #include <limits.h>
 #include <stdio.h>
@@ -35,6 +37,11 @@
 #include "scanutils.h"
 #include "tprintf.h"
 
+// workaround for "'off_t' was not declared in this scope" with -std=c++11
+#if !defined(HAVE_OFF_T)
+typedef long off_t;
+#endif  // off_t
+
 enum Flags {
   FL_SPLAT  = 0x01,   // Drop the value, do not assign
   FL_INV    = 0x02,   // Character-set with inverse
@@ -70,8 +77,7 @@ inline size_t LongBit() {
 }
 
 static inline int
-SkipSpace(FILE *s)
-{
+SkipSpace(FILE *s) {
   int p;
   while (isspace(p = fgetc(s)));
   ungetc(p, s);  // Make sure next char is available for reading
@@ -79,40 +85,36 @@ SkipSpace(FILE *s)
 }
 
 static inline void
-SetBit(unsigned long *bitmap, unsigned int bit)
-{
+SetBit(unsigned long *bitmap, unsigned int bit) {
   bitmap[bit/LongBit()] |= 1UL << (bit%LongBit());
 }
 
 static inline int
-TestBit(unsigned long *bitmap, unsigned int bit)
-{
+TestBit(unsigned long *bitmap, unsigned int bit) {
   return static_cast<int>(bitmap[bit/LongBit()] >> (bit%LongBit())) & 1;
 }
 
-static inline int DigitValue(int ch)
-{
+static inline int DigitValue(int ch, int base) {
   if (ch >= '0' && ch <= '9') {
-    return ch-'0';
-  } else if (ch >= 'A' && ch <= 'Z') {
+    if (base >= 10 || ch <= '7')
+      return ch-'0';
+  } else if (ch >= 'A' && ch <= 'Z' && base == 16) {
     return ch-'A'+10;
-  } else if (ch >= 'a' && ch <= 'z') {
+  } else if (ch >= 'a' && ch <= 'z' && base == 16) {
     return ch-'a'+10;
-  } else {
-    return -1;
   }
+  return -1;
 }
 
 // IO (re-)implementations -----------------------------------------------------
-uintmax_t streamtoumax(FILE* s, int base)
-{
+uintmax_t streamtoumax(FILE* s, int base) {
   int minus = 0;
   uintmax_t v = 0;
   int d, c = 0;
 
   for (c = fgetc(s);
     isspace(static_cast<unsigned char>(c)) && (c != EOF);
-    c = fgetc(s))
+    c = fgetc(s)) {}
 
   // Single optional + or -
   if (c == '-' || c == '+') {
@@ -134,20 +136,19 @@ uintmax_t streamtoumax(FILE* s, int base)
   } else if (base == 16) {
     if (c == '0') {
       c = fgetc(s);
-      if (c == 'x' && c == 'X') c = fgetc(s);
+      if (c == 'x' || c == 'X') c = fgetc(s);
     }
   }
 
   // Actual number parsing
-  for (; (c != EOF) && (d = DigitValue(c)) >= 0 && d < base; c = fgetc(s))
+  for (; (c != EOF) && (d = DigitValue(c, base)) >= 0; c = fgetc(s))
     v = v*base + d;
 
   ungetc(c, s);
   return minus ? -v : v;
 }
 
-double streamtofloat(FILE* s)
-{
+double streamtofloat(FILE* s) {
   int minus = 0;
   int v = 0;
   int d, c = 0;
@@ -165,25 +166,36 @@ double streamtofloat(FILE* s)
   }
 
   // Actual number parsing
-  for (; (c != EOF) && (d = DigitValue(c)) >= 0; c = fgetc(s))
+  for (; c != EOF && (d = DigitValue(c, 10)) >= 0; c = fgetc(s))
     v = v*10 + d;
   if (c == '.') {
-    for (c = fgetc(s); (c != EOF) && (d = DigitValue(c)) >= 0; c = fgetc(s)) {
+    for (c = fgetc(s); c != EOF && (d = DigitValue(c, 10)) >= 0; c = fgetc(s)) {
       w = w*10 + d;
       k *= 10;
     }
-  } else if (c == 'e' || c == 'E')
-    tprintf("WARNING: Scientific Notation not supported!");
-
-  ungetc(c, s);
+  }
   double f  = static_cast<double>(v)
             + static_cast<double>(w) / static_cast<double>(k);
+  if (c == 'e' || c == 'E') {
+    c = fgetc(s);
+    int expsign = 1;
+    if (c == '-' || c == '+') {
+      expsign = (c == '-') ? -1 : 1;
+      c = fgetc(s);
+    }
+    int exponent = 0;
+    for (; (c != EOF) && (d = DigitValue(c, 10)) >= 0; c = fgetc(s)) {
+      exponent = exponent * 10 + d;
+    }
+    exponent *= expsign;
+    f *= pow(10.0, static_cast<double>(exponent));
+  }
+  ungetc(c, s);
 
   return minus ? -f : f;
 }
 
-double strtofloat(const char* s)
-{
+double strtofloat(const char* s) {
   int minus = 0;
   int v = 0;
   int d;
@@ -199,14 +211,15 @@ double strtofloat(const char* s)
   }
 
   // Actual number parsing
-  for (; *s && (d = DigitValue(*s)) >= 0; s++)
+  for (; *s && (d = DigitValue(*s, 10)) >= 0; s++)
     v = v*10 + d;
   if (*s == '.') {
-    for (++s; *s && (d = DigitValue(*s)) >= 0; s++) {
+    for (++s; *s && (d = DigitValue(*s, 10)) >= 0; s++) {
       w = w*10 + d;
       k *= 10;
     }
-  } else if (*s == 'e' || *s == 'E')
+  }
+  if (*s == 'e' || *s == 'E')
     tprintf("WARNING: Scientific Notation not supported!");
 
   double f  = static_cast<double>(v)
@@ -215,20 +228,45 @@ double strtofloat(const char* s)
   return minus ? -f : f;
 }
 
-int fscanf(FILE* stream, const char *format, ...)
-{
+static int tvfscanf(FILE* stream, const char *format, va_list ap);
+
+int tfscanf(FILE* stream, const char *format, ...) {
   va_list ap;
   int rv;
 
   va_start(ap, format);
-  rv = vfscanf(stream, format, ap);
+  rv = tvfscanf(stream, format, ap);
   va_end(ap);
 
   return rv;
 }
 
-int vfscanf(FILE* stream, const char *format, va_list ap)
-{
+#ifdef EMBEDDED
+
+int fscanf(FILE* stream, const char *format, ...) {
+  va_list ap;
+  int rv;
+
+  va_start(ap, format);
+  rv = tvfscanf(stream, format, ap);
+  va_end(ap);
+
+  return rv;
+}
+
+int vfscanf(FILE* stream, const char *format, ...) {
+  va_list ap;
+  int rv;
+
+  va_start(ap, format);
+  rv = tvfscanf(stream, format, ap);
+  va_end(ap);
+
+  return rv;
+}
+#endif
+
+static int tvfscanf(FILE* stream, const char *format, va_list ap) {
   const char *p = format;
   char ch;
   int q = 0;
@@ -250,7 +288,8 @@ int vfscanf(FILE* stream, const char *format, va_list ap)
   enum Bail bail = BAIL_NONE;
   int sign;
   int converted = 0;    // Successful conversions
-  unsigned long matchmap[((1 << CHAR_BIT)+(LongBit()-1))/LongBit()];
+  unsigned long matchmap[((1 << CHAR_BIT)+(CHAR_BIT * sizeof(long) - 1)) /
+      (CHAR_BIT * sizeof(long))];
   int matchinv = 0;   // Is match map inverted?
   unsigned char range_start = 0;
   off_t start_off = ftell(stream);
@@ -273,21 +312,15 @@ int vfscanf(FILE* stream, const char *format, va_list ap)
         break;
 
       case ST_FLAGS:
-        switch (ch) {
-          case '*':
-            flags |= FL_SPLAT;
-          break;
-
-          case '0' ... '9':
-            width = (ch-'0');
-            state = ST_WIDTH;
-            flags |= FL_WIDTH;
-          break;
-
-          default:
-            state = ST_MODIFIERS;
-            p--;      // Process this character again
-          break;
+        if (ch == '*') {
+          flags |= FL_SPLAT;
+        } else if ('0' <= ch && ch <= '9') {
+          width = (ch-'0');
+          state = ST_WIDTH;
+          flags |= FL_WIDTH;
+        } else {
+          state = ST_MODIFIERS;
+          p--;      // Process this character again
         }
       break;
 
@@ -370,11 +403,11 @@ int vfscanf(FILE* stream, const char *format, va_list ap)
                 break;
               }
               val = streamtoumax(stream, base);
-              converted++;
               // fall through
 
             set_integer:
               if (!(flags & FL_SPLAT)) {
+                converted++;
                 switch(rank) {
                   case RANK_CHAR:
                     *va_arg(ap, unsigned char *)
@@ -417,15 +450,13 @@ int vfscanf(FILE* stream, const char *format, va_list ap)
 
               {
               double fval = streamtofloat(stream);
-              switch(rank) {
-                case RANK_INT:
+              if (!(flags & FL_SPLAT)) {
+                if (rank == RANK_INT)
                   *va_arg(ap, float *) = static_cast<float>(fval);
-                break;
-                case RANK_LONG:
+                else if (rank == RANK_LONG)
                   *va_arg(ap, double *) = static_cast<double>(fval);
-                break;
+                converted++;
               }
-              converted++;
               }
             break;
 
@@ -437,10 +468,11 @@ int vfscanf(FILE* stream, const char *format, va_list ap)
                   bail = BAIL_EOF;
                   break;
                 }
-                *sarg++ = q;
+                if (!(flags & FL_SPLAT)) {
+                  *sarg++ = q;
+                  converted++;
+                }
               }
-              if (!bail)
-                converted++;
             break;
 
             case 's':               // String
@@ -453,13 +485,15 @@ int vfscanf(FILE* stream, const char *format, va_list ap)
                   ungetc(q, stream);
                   break;
                 }
-                *sp++ = q;
+                if (!(flags & FL_SPLAT)) *sp = q;
+                sp++;
               }
-              if (sarg != sp) {
+              if (sarg == sp) {
+                bail = BAIL_EOF;
+              } else if (!(flags & FL_SPLAT)) {
                 *sp = '\0'; // Terminate output
                 converted++;
               } else {
-                bail = BAIL_EOF;
               }
             }
             break;
@@ -524,13 +558,14 @@ int vfscanf(FILE* stream, const char *format, va_list ap)
             ungetc(q, stream);
             break;
           }
-          *sarg++ = q;
+          if (!(flags & FL_SPLAT)) *sarg = q;
+          sarg++;
         }
-        if (oarg != sarg) {
+        if (oarg == sarg) {
+          bail = (q <= 0) ? BAIL_EOF : BAIL_ERR;
+        } else if (!(flags & FL_SPLAT)) {
           *sarg = '\0';
           converted++;
-        } else {
-          bail = (q <= 0) ? BAIL_EOF : BAIL_ERR;
         }
       break;
     }
@@ -542,8 +577,8 @@ int vfscanf(FILE* stream, const char *format, va_list ap)
   return converted;
 }
 
-int creat(const char *pathname, mode_t mode)
-{
+#ifdef EMBEDDED
+int creat(const char *pathname, mode_t mode) {
   return open(pathname, O_CREAT | O_TRUNC | O_WRONLY, mode);
 }
 
