@@ -79,13 +79,6 @@ typedef FEATURE_SET_STRUCT *FEATURE_SET;
 // classifier does not need to know the details of this data structure.
 typedef char *CHAR_FEATURES;
 
-typedef FEATURE_SET (*FX_FUNC)(TBLOB *, const DENORM&, const DENORM&,
-                               const INT_FX_RESULT_STRUCT&);
-
-struct FEATURE_EXT_STRUCT {
-  FX_FUNC Extractor;             // func to extract features
-};
-
 /*----------------------------------------------------------------------
     Macros for defining the parameters of a new features
 ----------------------------------------------------------------------*/
@@ -125,10 +118,8 @@ FEATURE ReadFeature(FILE *File, const FEATURE_DESC_STRUCT *FeatureDesc);
 
 FEATURE_SET ReadFeatureSet(FILE *File, const FEATURE_DESC_STRUCT *FeatureDesc);
 
-void WriteFeature(FILE *File, FEATURE Feature);
+void WriteFeature(FEATURE Feature, STRING* str);
 
-void WriteFeatureSet(FILE *File, FEATURE_SET FeatureSet);
-
-void WriteOldParamDesc(FILE *File, const FEATURE_DESC_STRUCT *FeatureDesc);
+void WriteFeatureSet(FEATURE_SET FeatureSet, STRING* str);
 
 #endif
