@@ -181,11 +181,12 @@ void Dawg::init(DawgType type, const STRING &lang,
   perm_ = perm;
   ASSERT_HOST(unicharset_size > 0);
   unicharset_size_ = unicharset_size;
-  // Set bit masks.
-  flag_start_bit_ = ceil(log(static_cast<double>(unicharset_size_)) / log(2.0));
+  // Set bit masks. We will use the value unicharset_size_ as a null char, so
+  // the actual number of unichars is unicharset_size_ + 1.
+  flag_start_bit_ = ceil(log(unicharset_size_ + 1.0) / log(2.0));
   next_node_start_bit_ = flag_start_bit_ + NUM_FLAG_BITS;
-  letter_mask_ = ~(~0 << flag_start_bit_);
-  next_node_mask_ = ~0 << (flag_start_bit_ + NUM_FLAG_BITS);
+  letter_mask_ = ~(~0ull << flag_start_bit_);
+  next_node_mask_ = ~0ull << (flag_start_bit_ + NUM_FLAG_BITS);
   flags_mask_ = ~(letter_mask_ | next_node_mask_);
 
   debug_level_ = debug_level;
