@@ -286,7 +286,7 @@ class Textord {
   BOOL_VAR_H(tosp_only_small_gaps_for_kern, false, "Better guess");
   BOOL_VAR_H(tosp_all_flips_fuzzy, false, "Pass ANY flip to context?");
   BOOL_VAR_H(tosp_fuzzy_limit_all, true,
-             "Dont restrict kn->sp fuzzy limit to tables");
+             "Don't restrict kn->sp fuzzy limit to tables");
   BOOL_VAR_H(tosp_stats_use_xht_gaps, true,
              "Use within xht gap for wd breaks");
   BOOL_VAR_H(tosp_use_xht_gaps, true,
@@ -294,7 +294,7 @@ class Textord {
   BOOL_VAR_H(tosp_only_use_xht_gaps, false,
              "Only use within xht gap for wd breaks");
   BOOL_VAR_H(tosp_rule_9_test_punct, false,
-             "Dont chng kn to space next to punct");
+             "Don't chng kn to space next to punct");
   BOOL_VAR_H(tosp_flip_fuzz_kn_to_sp, true, "Default flip");
   BOOL_VAR_H(tosp_flip_fuzz_sp_to_kn, true, "Default flip");
   BOOL_VAR_H(tosp_improve_thresh, false,
@@ -350,7 +350,7 @@ class Textord {
   double_VAR_H(tosp_fuzzy_kn_fraction, 0.5, "New fuzzy kn alg");
   double_VAR_H(tosp_fuzzy_sp_fraction, 0.5, "New fuzzy sp alg");
   double_VAR_H(tosp_min_sane_kn_sp, 1.5,
-               "Dont trust spaces less than this time kn");
+               "Don't trust spaces less than this time kn");
   double_VAR_H(tosp_init_guess_kn_mult, 2.2,
                "Thresh guess - mult kn by this");
   double_VAR_H(tosp_init_guess_xht_mult, 0.28,
@@ -358,15 +358,15 @@ class Textord {
   double_VAR_H(tosp_max_sane_kn_thresh, 5.0,
                "Multiplier on kn to limit thresh");
   double_VAR_H(tosp_flip_caution, 0.0,
-               "Dont autoflip kn to sp when large separation");
+               "Don't autoflip kn to sp when large separation");
   double_VAR_H(tosp_large_kerning, 0.19,
                "Limit use of xht gap with large kns");
   double_VAR_H(tosp_dont_fool_with_small_kerns, -1,
                "Limit use of xht gap with odd small kns");
   double_VAR_H(tosp_near_lh_edge, 0,
-               "Dont reduce box if the top left is non blank");
+               "Don't reduce box if the top left is non blank");
   double_VAR_H(tosp_silly_kn_sp_gap, 0.2,
-               "Dont let sp minus kn get too small");
+               "Don't let sp minus kn get too small");
   double_VAR_H(tosp_pass_wide_fuzz_sp_to_context, 0.75,
                "How wide fuzzies need context");
   // tordmain.cpp ///////////////////////////////////////////
