@@ -38,13 +38,18 @@
 
 #include "allheaders.h"
 
-const ERRCODE BLOCKLESS_BLOBS = "Warning:some blobs assigned to no block";
+// Gridsize for word grid when reassigning diacritics to words. Not critical.
+const int kWordGridSize = 50;
 
 #undef EXTERN
 #define EXTERN
 
 #define MAX_NEAREST_DIST  600    //for block skew stats
 
+namespace tesseract {
+
+CLISTIZE(WordWithBox)
+
 /**********************************************************************
  * SetBlobStrokeWidth
  *
@@ -143,7 +148,6 @@ void SetBlobStrokeWidth(Pix* pix, BLOBNBOX* blob) {
   }
 }
 
-
 /**********************************************************************
  * assign_blobs_to_blocks2
  *
@@ -193,7 +197,6 @@ void assign_blobs_to_blocks2(Pix* pix,
   }
 }
 
-namespace tesseract {
 /**********************************************************************
  * find_components
  *
@@ -360,9 +363,11 @@ void Textord::cleanup_nontext_block(BLOCK* block) {
   // Non-text blocks must contain at least one row.
   ROW_IT row_it(block->row_list());
   if (row_it.empty()) {
-    float height = block->bounding_box().height();
-    inT32 zero = 0;
-    ROW* row = new ROW(0, &zero, NULL, height / 2.0f, height / 4.0f,
+    TBOX box = block->bounding_box();
+    float height = box.height();
+    inT32 xstarts[2] = {box.left(), box.right()};
+    double coeffs[3] = {0.0, 0.0, static_cast<double>(box.bottom())};
+    ROW* row = new ROW(1, xstarts, coeffs, height / 2.0f, height / 4.0f,
                        height / 4.0f, 0, 1);
     row_it.add_after_then_move(row);
   }
@@ -398,9 +403,7 @@ void Textord::cleanup_nontext_block(BLOCK* block) {
  * Delete empty blocks, rows from the page.
  **********************************************************************/
 
-void Textord::cleanup_blocks(                    //remove empties
-                             BLOCK_LIST *blocks  //list
-                            ) {
+void Textord::cleanup_blocks(bool clean_noise, BLOCK_LIST* blocks) {
   BLOCK_IT block_it = blocks;    //iterator
   ROW_IT row_it;                 //row iterator
 
@@ -417,22 +420,24 @@ void Textord::cleanup_blocks(                    //remove empties
     }
     num_rows = 0;
     num_rows_all = 0;
-    row_it.set_to_list(block->row_list());
-    for (row_it.mark_cycle_pt(); !row_it.cycled_list(); row_it.forward()) {
-      ++num_rows_all;
-      clean_small_noise_from_words(row_it.data());
-      if ((textord_noise_rejrows && !row_it.data()->word_list()->empty() &&
-           clean_noise_from_row(row_it.data())) ||
-          row_it.data()->word_list()->empty()) {
-        delete row_it.extract();  // lose empty row.
-      } else {
-        if (textord_noise_rejwords)
-          clean_noise_from_words(row_it.data());
-        if (textord_blshift_maxshift >= 0)
-          tweak_row_baseline(row_it.data(),
-                             textord_blshift_maxshift,
-                             textord_blshift_xfraction);
-        ++num_rows;
+    if (clean_noise) {
+      row_it.set_to_list(block->row_list());
+      for (row_it.mark_cycle_pt(); !row_it.cycled_list(); row_it.forward()) {
+        ROW* row = row_it.data();
+        ++num_rows_all;
+        clean_small_noise_from_words(row);
+        if ((textord_noise_rejrows && !row->word_list()->empty() &&
+             clean_noise_from_row(row)) ||
+            row->word_list()->empty()) {
+          delete row_it.extract();  // lose empty row.
+        } else {
+          if (textord_noise_rejwords)
+            clean_noise_from_words(row_it.data());
+          if (textord_blshift_maxshift >= 0)
+            tweak_row_baseline(row, textord_blshift_maxshift,
+                               textord_blshift_xfraction);
+          ++num_rows;
+        }
       }
     }
     if (block->row_list()->empty()) {
@@ -638,16 +643,16 @@ void Textord::clean_noise_from_words(          //remove empties
         && (!word_it.at_first () || !blob_it.at_first ()))
         dot_count += 2;
     }
-    if (dot_count > 2) {
+    if (dot_count > 2 && !word->flag(W_REP_CHAR)) {
       if (dot_count > norm_count * textord_noise_normratio * 2)
         word_dud[word_index] = 2;
       else if (dot_count > norm_count * textord_noise_normratio)
         word_dud[word_index] = 1;
       else
         word_dud[word_index] = 0;
-    }
-    else
+    } else {
       word_dud[word_index] = 0;
+    }
     if (word_dud[word_index] == 2)
       dud_words++;
     else
@@ -659,11 +664,11 @@ void Textord::clean_noise_from_words(          //remove empties
   for (word_it.mark_cycle_pt (); !word_it.cycled_list (); word_it.forward ()) {
     if (word_dud[word_index] == 2
     || (word_dud[word_index] == 1 && dud_words > ok_words)) {
-      word = word_it.data ();    //current word
-                                 //rejected blobs
-      blob_it.set_to_list (word->rej_cblob_list ());
-                                 //move from blobs
-      blob_it.add_list_after (word->cblob_list ());
+      word = word_it.data();  // Current word.
+      // Previously we threw away the entire word.
+      // Now just aggressively throw all small blobs into the reject list, where
+      // the classifier can decide whether they are actually needed.
+      word->CleanNoise(textord_noise_sizelimit * row->x_height());
     }
     word_index++;
   }
@@ -703,6 +708,172 @@ void Textord::clean_small_noise_from_words(ROW *row) {
     }
   }
 }
+
+// Local struct to hold a group of blocks.
+struct BlockGroup {
+  BlockGroup() : rotation(1.0f, 0.0f), angle(0.0f), min_xheight(1.0f) {}
+  explicit BlockGroup(BLOCK* block)
+      : bounding_box(block->bounding_box()),
+        rotation(block->re_rotation()),
+        angle(block->re_rotation().angle()),
+        min_xheight(block->x_height()) {
+    blocks.push_back(block);
+  }
+  // Union of block bounding boxes.
+  TBOX bounding_box;
+  // Common rotation of the blocks.
+  FCOORD rotation;
+  // Angle of rotation.
+  float angle;
+  // Min xheight of the blocks.
+  float min_xheight;
+  // Collection of borrowed pointers to the blocks in the group.
+  GenericVector<BLOCK*> blocks;
+};
+
+// Groups blocks by rotation, then, for each group, makes a WordGrid and calls
+// TransferDiacriticsToWords to copy the diacritic blobs to the most
+// appropriate words in the group of blocks. Source blobs are not touched.
+void Textord::TransferDiacriticsToBlockGroups(BLOBNBOX_LIST* diacritic_blobs,
+                                              BLOCK_LIST* blocks) {
+  // Angle difference larger than this is too much to consider equal.
+  // They should only be in multiples of M_PI/2 anyway.
+  const double kMaxAngleDiff = 0.01;  // About 0.6 degrees.
+  PointerVector<BlockGroup> groups;
+  BLOCK_IT bk_it(blocks);
+  for (bk_it.mark_cycle_pt(); !bk_it.cycled_list(); bk_it.forward()) {
+    BLOCK* block = bk_it.data();
+    if (block->poly_block() != NULL && !block->poly_block()->IsText()) {
+      continue;
+    }
+    // Linear search of the groups to find a matching rotation.
+    float block_angle = block->re_rotation().angle();
+    int best_g = 0;
+    float best_angle_diff = MAX_FLOAT32;
+    for (int g = 0; g < groups.size(); ++g) {
+      double angle_diff = fabs(block_angle - groups[g]->angle);
+      if (angle_diff > M_PI) angle_diff = fabs(angle_diff - 2.0 * M_PI);
+      if (angle_diff < best_angle_diff) {
+        best_angle_diff = angle_diff;
+        best_g = g;
+      }
+    }
+    if (best_angle_diff > kMaxAngleDiff) {
+      groups.push_back(new BlockGroup(block));
+    } else {
+      groups[best_g]->blocks.push_back(block);
+      groups[best_g]->bounding_box += block->bounding_box();
+      float x_height = block->x_height();
+      if (x_height < groups[best_g]->min_xheight)
+        groups[best_g]->min_xheight = x_height;
+    }
+  }
+  // Now process each group of blocks.
+  PointerVector<WordWithBox> word_ptrs;
+  for (int g = 0; g < groups.size(); ++g) {
+    const BlockGroup* group = groups[g];
+    WordGrid word_grid(group->min_xheight, group->bounding_box.botleft(),
+                       group->bounding_box.topright());
+    for (int b = 0; b < group->blocks.size(); ++b) {
+      ROW_IT row_it(group->blocks[b]->row_list());
+      for (row_it.mark_cycle_pt(); !row_it.cycled_list(); row_it.forward()) {
+        ROW* row = row_it.data();
+        // Put the words of the row into the grid.
+        WERD_IT w_it(row->word_list());
+        for (w_it.mark_cycle_pt(); !w_it.cycled_list(); w_it.forward()) {
+          WERD* word = w_it.data();
+          WordWithBox* box_word = new WordWithBox(word);
+          word_grid.InsertBBox(true, true, box_word);
+          // Save the pointer where it will be auto-deleted.
+          word_ptrs.push_back(box_word);
+        }
+      }
+    }
+    FCOORD rotation = group->rotation;
+    // Make it a forward rotation that will transform blob coords to block.
+    rotation.set_y(-rotation.y());
+    TransferDiacriticsToWords(diacritic_blobs, rotation, &word_grid);
+  }
+}
+
+// Places a copy of blobs that are near a word (after applying rotation to the
+// blob) in the most appropriate word, unless there is doubt, in which case a
+// blob can end up in two words. Source blobs are not touched.
+void Textord::TransferDiacriticsToWords(BLOBNBOX_LIST* diacritic_blobs,
+                                        const FCOORD& rotation,
+                                        WordGrid* word_grid) {
+  WordSearch ws(word_grid);
+  BLOBNBOX_IT b_it(diacritic_blobs);
+  // Apply rotation to each blob before finding the nearest words. The rotation
+  // allows us to only consider above/below placement and not left/right on
+  // vertical text, because all text is horizontal here.
+  for (b_it.mark_cycle_pt(); !b_it.cycled_list(); b_it.forward()) {
+    BLOBNBOX* blobnbox = b_it.data();
+    TBOX blob_box = blobnbox->bounding_box();
+    blob_box.rotate(rotation);
+    ws.StartRectSearch(blob_box);
+    // Above/below refer to word position relative to diacritic. Since some
+    // scripts eg Kannada/Telugu habitually put diacritics below words, and
+    // others eg Thai/Vietnamese/Latin put most diacritics above words, try
+    // for both if there isn't much in it.
+    WordWithBox* best_above_word = NULL;
+    WordWithBox* best_below_word = NULL;
+    int best_above_distance = 0;
+    int best_below_distance = 0;
+    for (WordWithBox* word = ws.NextRectSearch(); word != NULL;
+         word = ws.NextRectSearch()) {
+      if (word->word()->flag(W_REP_CHAR)) continue;
+      TBOX word_box = word->true_bounding_box();
+      int x_distance = blob_box.x_gap(word_box);
+      int y_distance = blob_box.y_gap(word_box);
+      if (x_distance > 0) {
+        // Arbitrarily divide x-distance by 2 if there is a major y overlap,
+        // and the word is to the left of the diacritic. If the
+        // diacritic is a dropped broken character between two words, this will
+        // help send all the pieces to a single word, instead of splitting them
+        // over the 2 words.
+        if (word_box.major_y_overlap(blob_box) &&
+            blob_box.left() > word_box.right()) {
+          x_distance /= 2;
+        }
+        y_distance += x_distance;
+      }
+      if (word_box.y_middle() > blob_box.y_middle() &&
+          (best_above_word == NULL || y_distance < best_above_distance)) {
+        best_above_word = word;
+        best_above_distance = y_distance;
+      }
+      if (word_box.y_middle() <= blob_box.y_middle() &&
+          (best_below_word == NULL || y_distance < best_below_distance)) {
+        best_below_word = word;
+        best_below_distance = y_distance;
+      }
+    }
+    bool above_good =
+        best_above_word != NULL &&
+        (best_below_word == NULL ||
+         best_above_distance < best_below_distance + blob_box.height());
+    bool below_good =
+        best_below_word != NULL && best_below_word != best_above_word &&
+        (best_above_word == NULL ||
+         best_below_distance < best_above_distance + blob_box.height());
+    if (below_good) {
+      C_BLOB* copied_blob = C_BLOB::deep_copy(blobnbox->cblob());
+      copied_blob->rotate(rotation);
+      // Put the blob into the word's reject blobs list.
+      C_BLOB_IT blob_it(best_below_word->RejBlobs());
+      blob_it.add_to_end(copied_blob);
+    }
+    if (above_good) {
+      C_BLOB* copied_blob = C_BLOB::deep_copy(blobnbox->cblob());
+      copied_blob->rotate(rotation);
+      // Put the blob into the word's reject blobs list.
+      C_BLOB_IT blob_it(best_above_word->RejBlobs());
+      blob_it.add_to_end(copied_blob);
+    }
+  }
+}
+
 }  // tesseract
 
 /**********************************************************************
@@ -818,33 +989,3 @@ void tweak_row_baseline(ROW *row,
   free_mem(xstarts);
   free_mem(coeffs);
 }
-
-/**********************************************************************
- * blob_y_order
- *
- * Sort function to sort blobs in y from page top.
- **********************************************************************/
-
-inT32 blob_y_order(              //sort function
-                   void *item1,  //items to compare
-                   void *item2) {
-                                 //converted ptr
-  BLOBNBOX *blob1 = *(BLOBNBOX **) item1;
-                                 //converted ptr
-  BLOBNBOX *blob2 = *(BLOBNBOX **) item2;
-
-  if (blob1->bounding_box ().bottom () > blob2->bounding_box ().bottom ())
-    return -1;
-  else if (blob1->bounding_box ().bottom () <
-    blob2->bounding_box ().bottom ())
-    return 1;
-  else {
-    if (blob1->bounding_box ().left () < blob2->bounding_box ().left ())
-      return -1;
-    else if (blob1->bounding_box ().left () >
-      blob2->bounding_box ().left ())
-      return 1;
-    else
-      return 0;
-  }
-}
